==> openshift-model-6.5.1-sources.jar: io/fabric8/openshift/api/model/ConfigMapBuildSourceFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ConfigMapBuildSourceFluent<A extends ConfigMapBuildSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConfigMap instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getConfigMap();
  public LocalObjectReference buildConfigMap();
  public A withConfigMap(LocalObjectReference configMap);
  public Boolean hasConfigMap();
  public A withNewConfigMap(String name);
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> withNewConfigMap();
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> withNewConfigMapLike(LocalObjectReference item);
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> editConfigMap();
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> editOrNewConfigMap();
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> editOrNewConfigMapLike(LocalObjectReference item);
  public String getDestinationDir();
  public A withDestinationDir(String destinationDir);
  public Boolean hasDestinationDir();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConfigMapNested<N> extends Nested<N>,LocalObjectReferenceFluent<ConfigMapBuildSourceFluent.ConfigMapNested<N>>{
    public N and();
    public N endConfigMap();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/ConfigMapBuildSourceFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

 /**
  * Generated
  */
public interface ConfigMapBuildSourceFluent<A extends ConfigMapBuildSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConfigMap instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getConfigMap();
  public LocalObjectReference buildConfigMap();
  public A withConfigMap(LocalObjectReference configMap);
  public Boolean hasConfigMap();
  public A withNewConfigMap(String name);
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> withNewConfigMap();
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> withNewConfigMapLike(LocalObjectReference item);
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> editConfigMap();
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> editOrNewConfigMap();
  public ConfigMapBuildSourceFluent.ConfigMapNested<A> editOrNewConfigMapLike(LocalObjectReference item);
  public String getDestinationDir();
  public A withDestinationDir(String destinationDir);
  public Boolean hasDestinationDir();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConfigMapNested<N> extends Nested<N>,LocalObjectReferenceFluent<ConfigMapBuildSourceFluent.ConfigMapNested<N>>{
    public N and();
    public N endConfigMap();
    
  }
  
}
